@@ -9,8 +9,6 @@
 #include <MailTransport/Transport>
 
 #include "accountwizard_debug.h"
-#include <KLocalizedString>
-#include <KMessageBox>
 
 ServerTest::ServerTest(QObject *parent)
     : QObject(parent)
@@ -30,7 +28,7 @@ void ServerTest::test(const QString &server, const QString &protocol)
     qCDebug(ACCOUNTWIZARD_LOG) << server << protocol;
     m_serverTest->setServer(server);
     m_serverTest->setProtocol(protocol);
-    if (protocol == QLatin1String("submission")) {
+    if (protocol == QLatin1StringView("submission")) {
         m_serverTest->setProtocol(QStringLiteral("smtp"));
         m_serverTest->setPort(MailTransport::Transport::EnumEncryption::None, 587);
         m_serverTest->setPort(MailTransport::Transport::EnumEncryption::SSL, 0); // No ssl port for submission
@@ -46,11 +44,8 @@ void ServerTest::testFinished(const QVector<int> &list)
     } else if (list.contains(MailTransport::Transport::EnumEncryption::SSL)) {
         Q_EMIT testResult(QStringLiteral("ssl"));
     } else {
-        KMessageBox::information(nullptr,
-                                 i18n("There seems to be a problem in reaching this server "
-                                      "or choosing a safe way to sent the credentials to server. We advise you to "
-                                      "check the settings of the account and adjust it manually if needed."),
-                                 i18n("Autodetecting settings failed"));
         Q_EMIT testFail();
     }
 }
+
+#include "moc_servertest.cpp"
